#!/usr/bin/perl -w
# $Id: Makefile.PL,v 1.9 2003/11/16 07:07:26 ianb Exp $
# ianb@nessie.mcc.ac.uk 20031019

use ExtUtils::MakeMaker;

WriteMakefile(NAME=>"mp3lint",
			  VERSION_FROM=>"bin/mp3lint",
			  EXE_FILES=>["bin/mp3lint", "bin/mp3lintskip", "bin/mp3lintsum"],
			  PL_FILES=>{"docs/mp3lint-tools.pod.PL" => "docs/mp3lint-tools.pod" },
			  MAN1PODS=>{ "bin/mp3lint"            => '${INST_MAN1DIR}/mp3lint.1',
						  "bin/mp3lintskip"        => '${INST_MAN1DIR}/mp3lintskip.1',
						  "bin/mp3lintsum"         => '${INST_MAN1DIR}/mp3lintsum.1',},
			  MAN3PODS=>{ "docs/mp3lint-tools.pod" => '${INST_MAN3DIR}/mp3lint-tools.3',},
			  PREREQ_PM=>{'MP3::Archive' => 0},
			  clean=>{ FILES => "docs/mp3lint-tools.pod" },
			  dist=>{ COMPRESS=>"gzip -9f", SUFFIX=>"gz", }, 
			  ($] >= 5.005
			   ? (ABSTRACT   => 'Checks a tree of audio files',
				  AUTHOR     => 'Ian Beckwith <ianb@nessie.mcc.ac.uk>')
			   : ()),
			  );


# man 5 stuff adapted from vipul's razor, http://razor.sf.net

{
package MY;

sub constants {

    my $self = shift;
    my $inherited = $self->SUPER::constants(@_);

    my $add = q{

# begin mp3lint
MAN5PODS = docs/mp3lintrc.pod
INST_MAN5DIR = blib/man5
INSTALLMAN5DIR = $(PREFIX)/man/man5
DESTINSTALLMAN5DIR = $(DESTDIR)$(INSTALLMAN5DIR)
INSTALLSITEMAN5DIR = $(SITEPREFIX)/man/man5
DESTINSTALLSITEMAN5DIR = $(DESTDIR)$(INSTALLSITEMAN5DIR)
INSTALLVENDORMAN5DIR = $(VENDORPREFIX)/man/man5
DESTINSTALLVENDORMAN5DIR = $(DESTDIR)$(INSTALLVENDORMAN5DIR)
MAN5EXT = 5
INST_SYSCONFDIR = blib/etc
INSTALLSYSCONFDIR = /etc
DESTINSTALLSYSCONFDIR = $(DESTDIR)$(INSTALLSYSCONFDIR)	
# end mp3lint

};

    return $inherited . $add;

}


sub MY::top_targets {

    use Config;

    my $self = shift;
    my $inherited = $self->SUPER::top_targets(@_);

	my ($perlh) = $self->catfile($Config{archlibexp}, 'CORE', "perl.h");

    my $noecho = q{NOECHO = @} unless $inherited =~ /NOECHO/;

    my $add = sprintf <<'MAKE_FRAG', $perlh, $perlh, $perlh, $perlh;

# begin mp3lint
config :: $(INST_MAN5DIR)/.exists $(INST_SYSCONFDIR)/.exists
	@$(NOOP)

$(INST_MAN5DIR)/.exists :: %s
	@$(MKPATH) $(INST_MAN5DIR)
	@$(EQUALIZE_TIMESTAMP) %s $(INST_MAN5DIR)/.exists
	-@$(CHMOD) $(PERM_RWX) $(INST_MAN5DIR)

$(INST_SYSCONFDIR)/.exists :: %s
	@$(MKPATH) $(INST_SYSCONFDIR)
	@$(EQUALIZE_TIMESTAMP) %s $(INST_SYSCONFDIR)/.exists
	-@$(CHMOD) $(PERM_RWX) $(INST_SYSCONFDIR)
	@$(CP) etc/mp3lintrc $(INST_SYSCONFDIR)
# end mp3lint

MAKE_FRAG

    return $inherited . $add;
}


sub MY::manifypods {
    my $self = shift;
    my $inherited = $self->SUPER::manifypods(@_);

    $inherited =~ s{^(manifypods : .*)\\}{$1 manifypods-local \\}m;

    # MakeMaker 6.06_x through 6.13 eliminated the POD2MAN macro.
    my $pod2man = "";
	unless ($inherited =~ /^POD2MAN\b/m)
	{
		$pod2man=q{POD2MAN = $(POD2MAN_EXE)};
	}
	my $manifypods_local = sprintf <<'MAKE_FRAG', $pod2man;

# begin mp3lint
%s

manifypods-local : docs/mp3lintrc.pod
	$(POD2MAN) -s $(MAN5EXT) docs/mp3lintrc.pod $(INST_MAN5DIR)/mp3lintrc.$(MAN5EXT) 

#end mp3lint
MAKE_FRAG

    return $inherited . "\n" . $manifypods_local;

}


sub MY::install {

  my $self = shift;
  my $inherited = $self->SUPER::install(@_);
  my $conf="\t\t\$(INST_SYSCONFDIR) \$(DESTINSTALLSYSCONFDIR)";
  $inherited =~ s/(^\s*\$\(INST_MAN)3(DIR\s*.*MAN)3(DIR\))/${1}3${2}3$3 \\\n${1}5${2}5$3 \\\n$conf/gm;

  return $inherited;
}

}
